import { client, navigateTo } from "../../index.js";
import { clear, fill_errors } from "../../utils/formUtils.js";
import AbstractNonAuthentifiedView from "../abstracts/AbstractNonAuthentified.js";

async function login()
{
	let username = document.getElementById("username-input").value;
	let password = document.getElementById("password-input").value;
	
	let response = await client.login(username, password);

	if (response.status == 200) {
		await client.notice.disconnect();
		await client.notice.connect();
		navigateTo("/home");
	} else {
		let error = await response.json();
		fill_errors(error, "innerHTML");
	}
}

export default class extends AbstractNonAuthentifiedView {
    constructor(params) {
        super(params, "Login", "/home");
	}

	async postInit()
	{
		let usernameField = document.getElementById('username-input');
		usernameField.addEventListener('keydown', ev => {
			if (ev.key === 'Enter')
				login();
		});
		usernameField.focus();
		let passwordField = document.getElementById('password-input');
		passwordField.addEventListener('keydown', ev => {
			if (ev.key === 'Enter')
				login();
		});
		document.getElementById("login-button").onclick = login;
	}

    async getHtml() {
        return `
			<div class=form>
				<label>Login</label>
				<link rel="stylesheet" href="/static/css/accounts/login.css">
				<input type="text" id="username-input" placeholder="username">
				<input type="password" id="password-input" placeholder="password">
				<input type="button" value="Login" id="login-button">
				<span id="error"></span>
				<a href="/register" class="nav__link" data-link>Register</a>
			</div>
        `;
    }
}
